@@ -21,8 +21,8 @@
 #include "MainWindow.h"
 
 // Qt includes
-#include <QApplication>
 #include <QtCore/QTimer>
+#include <QtGui/QApplication>
 #include <QtGui/QVBoxLayout>
 
 // KDE includes
@@ -30,6 +30,8 @@
 #include <KActionCollection>
 #include <KDebug>
 #include "kmessagewidget.h"
+#include <KProcess>
+#include <KStandardDirs>
 #include <Solid/Device>
 #include <Solid/AcAdapter>
 
@@ -45,8 +47,9 @@
 
 MainWindow::MainWindow()
     : MuonMainWindow()
-    , m_settingsDialog(0)
-    , m_historyDialog(0)
+    , m_settingsDialog(nullptr)
+    , m_historyDialog(nullptr)
+    , m_checkerProcess(nullptr)
 {
     initGUI();
     QTimer::singleShot(10, this, SLOT(initObject()));
@@ -66,21 +69,28 @@ void MainWindow::initGUI()
     m_powerMessage->setMessageType(KMessageWidget::Warning);
     checkPlugState();
 
+    m_distUpgradeMessage = new KMessageWidget(mainWidget);
+    m_distUpgradeMessage->hide();
+    m_distUpgradeMessage->setMessageType(KMessageWidget::Information);
+    m_distUpgradeMessage->setText(i18nc("Notification when a new version of Kubuntu is available",
+                                        "A new version of Kubuntu is available."));
+
     m_progressWidget = new ProgressWidget(mainWidget);
     m_progressWidget->hide();
 
     m_updaterWidget = new UpdaterWidget(mainWidget);
-    connect(this, SIGNAL(backendReady(QApt::Backend *)),
-            m_updaterWidget, SLOT(setBackend(QApt::Backend *)));
+    connect(this, SIGNAL(backendReady(QApt::Backend*)),
+            m_updaterWidget, SLOT(setBackend(QApt::Backend*)));
 
     m_changelogWidget = new ChangelogWidget(this);
     m_changelogWidget->hide();
-    connect(this, SIGNAL(backendReady(QApt::Backend *)),
-            m_changelogWidget, SLOT(setBackend(QApt::Backend *)));
+    connect(this, SIGNAL(backendReady(QApt::Backend*)),
+            m_changelogWidget, SLOT(setBackend(QApt::Backend*)));
     connect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
             m_changelogWidget, SLOT(setPackage(QApt::Package*)));
 
     mainLayout->addWidget(m_powerMessage);
+    mainLayout->addWidget(m_distUpgradeMessage);
     mainLayout->addWidget(m_progressWidget);
     mainLayout->addWidget(m_updaterWidget);
     mainLayout->addWidget(m_changelogWidget);
@@ -89,6 +99,8 @@ void MainWindow::initGUI()
 
     mainWidget->setLayout(mainLayout);
     setCentralWidget(mainWidget);
+
+    checkDistUpgrade();
 }
 
 void MainWindow::initObject()
@@ -96,10 +108,10 @@ void MainWindow::initObject()
     MuonMainWindow::initObject();
     setActionsEnabled(); //Get initial enabled/disabled state
 
-    connect(m_backend, SIGNAL(downloadProgress(int, int, int)),
-            m_progressWidget, SLOT(updateDownloadProgress(int, int, int)));
-    connect(m_backend, SIGNAL(commitProgress(const QString &, int)),
-            m_progressWidget, SLOT(updateCommitProgress(const QString &, int)));
+    connect(m_backend, SIGNAL(downloadProgress(int,int,int)),
+            m_progressWidget, SLOT(updateDownloadProgress(int,int,int)));
+    connect(m_backend, SIGNAL(commitProgress(QString,int)),
+            m_progressWidget, SLOT(updateCommitProgress(QString,int)));
 }
 
 void MainWindow::setupActions()
@@ -138,6 +150,11 @@ void MainWindow::setupActions()
     m_historyAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
     connect(m_historyAction, SIGNAL(triggered()), this, SLOT(showHistoryDialog()));
 
+    KAction *distUpgradeAction = new KAction(KIcon("system-software-update"), i18nc("@action", "Upgrade"), this);
+    connect(distUpgradeAction, SIGNAL(activated()), this, SLOT(launchDistUpgrade()));
+
+    m_distUpgradeMessage->addAction(distUpgradeAction);
+
     setActionsEnabled(false);
 
     setupGUI((StandardWindowOption)(KXmlGuiWindow::Default & ~KXmlGuiWindow::StatusBar));
@@ -180,6 +197,7 @@ void MainWindow::workerEvent(QApt::WorkerEvent event)
         break;
     case QApt::CommitChangesStarted:
         m_progressWidget->setHeaderText(i18nc("@info", "<title>Installing Updates</title>"));
+        m_progressWidget->hideCancelButton();
         QApplication::restoreOverrideCursor();
         break;
     default:
@@ -276,7 +294,7 @@ void MainWindow::editSettings()
 void MainWindow::closeSettingsDialog()
 {
     m_settingsDialog->deleteLater();
-    m_settingsDialog = 0;
+    m_settingsDialog = nullptr;
 }
 
 void MainWindow::showHistoryDialog()
@@ -306,7 +324,7 @@ void MainWindow::closeHistoryDialog()
                               "HistoryDialog");
     m_historyDialog->saveDialogSize(dialogConfig, KConfigBase::Persistent);
     m_historyDialog->deleteLater();
-    m_historyDialog = 0;
+    m_historyDialog = nullptr;
 }
 
 void MainWindow::checkPlugState()
@@ -320,7 +338,7 @@ void MainWindow::checkPlugState()
     
     bool isPlugged = false;
 
-    foreach(Solid::Device device_ac, acAdapters) {
+    for(Solid::Device device_ac : acAdapters) {
         Solid::AcAdapter* acAdapter = device_ac.as<Solid::AcAdapter>();
         isPlugged |= acAdapter->isPlugged();
         connect(acAdapter, SIGNAL(plugStateChanged(bool,QString)),
@@ -334,3 +352,26 @@ void MainWindow::updatePlugState(bool plugged)
 {
     plugged ? m_powerMessage->hide() : m_powerMessage->show();
 }
+
+void MainWindow::checkDistUpgrade()
+{
+    QString checkerFile = KStandardDirs::locate("data", "muon-notifier/releasechecker");
+
+    m_checkerProcess = new KProcess(this);
+    m_checkerProcess->setProgram(QStringList() << "/usr/bin/python" << checkerFile);
+    connect(m_checkerProcess, SIGNAL(finished(int)), this, SLOT(checkerFinished(int)));
+    m_checkerProcess->start();
+}
+
+void MainWindow::checkerFinished(int res)
+{
+    if (res == 0) {
+        m_distUpgradeMessage->show();
+    }
+}
+
+void MainWindow::launchDistUpgrade()
+{
+    KProcess::startDetached(QStringList() << "python"
+                            << "/usr/share/pyshared/UpdateManager/DistUpgradeFetcherKDE.py");
+}
